.. _developer_guide:

Developer Guide
###############

The developer guide is intended for anybody who would like to start developing their own device
simulations. Some details of the framework are described as well as the implementation of a new
device from start to finish.

.. toctree::
    :maxdepth: 2

    framework_details
    writing_devices
    developing_lewis
    release_checklist

.. seealso::

    For details regarding the available modules, classes and functions, please refer to
    the :ref:`api_documentation`.
